@@ -144,7 +144,7 @@ class AVISO_fetch(object):
         """
         assert (map in ['madt', 'msla'])
 
-        self.cfg['source_filename'] = "dataset-duacs-dt-%s-global-merged-%s" % (self.cfg['type'], map)
+        self.cfg['source_filename'] = "dataset-duacs-dt-global-allsat-%s" % (map,)
         self.logger.debug("source_filename: %s" % self.cfg['source_filename'])
 
     def set_dataset(self, map, var):
@@ -155,13 +155,22 @@ class AVISO_fetch(object):
         self.set_source_filename(map)
 
         if var == 'h':
-            url = "%s/%s-h-daily" % (self.cfg['urlbase'], self.cfg['source_filename'])
+            url = "%s/%s-h" % (self.cfg['urlbase'], self.cfg['source_filename'])
         if var in ['u', 'v']:
-            url = "%s/%s-uv-daily" % (self.cfg['urlbase'], self.cfg['source_filename'])
+            url = "%s/%s-uv" % (self.cfg['urlbase'], self.cfg['source_filename'])
 
-        dataset = open_url(url)
-        self.logger.debug("Dataset on the DAP server is ready")
-        return dataset
+        ntries = 40
+        for i in range(ntries):
+            self.logger.info("Connecting with the URL: %s" % url)
+            try:
+                dataset = open_url(url)
+                self.logger.debug("Dataset on the DAP server is ready")
+                return dataset
+            except:
+                waitingtime = 30+i*20
+                self.logger.warn("Failed to open_url. I'll try again in %s" %
+                        waitingtime)
+                time.sleep(waitingtime)
 
     def download_time(self, dataset):
         """
@@ -218,8 +227,8 @@ class AVISO_fetch(object):
         self.logger.debug("Downloading LonLat")
         data = {}
         limits = self.cfg['limits']
-        Lat = dataset['NbLatitudes'][:].astype('f')
-        Lon = dataset['NbLongitudes'][:].astype('f')
+        Lat = dataset['lat'][:].astype('f')
+        Lon = dataset['lon'][:].astype('f')
 
         # If data is requested as -180/180, convert to 0/360,
         #   which is the pattern in AVISO
@@ -272,16 +281,16 @@ class AVISO_fetch(object):
             self.download_time(dataset)
             self.download_LonLat(dataset)
 
-            self.download_var('ssh', dataset['Grid_0001']['Grid_0001'], dataset['Grid_0001'].attributes)
+            self.download_var('ssh', dataset['adt']['adt'], dataset['adt'].attributes)
             dataset = self.set_dataset('madt', 'u')
-            self.download_var('u', dataset['Grid_0001']['Grid_0001'], dataset['Grid_0001'].attributes)
-            self.download_var('v', dataset['Grid_0002']['Grid_0002'], dataset['Grid_0002'].attributes)
+            self.download_var('u', dataset['u']['u'], dataset['u'].attributes)
+            self.download_var('v', dataset['v']['v'], dataset['v'].attributes)
 
             dataset = self.set_dataset('msla', 'h')
-            self.download_var('eta', dataset['Grid_0001']['Grid_0001'], dataset['Grid_0001'].attributes)
-            dataset = self.set_dataset('madt', 'u')
-            self.download_var('u_anom', dataset['Grid_0001']['Grid_0001'], dataset['Grid_0001'].attributes)
-            self.download_var('v_anom', dataset['Grid_0002']['Grid_0002'], dataset['Grid_0002'].attributes)
+            self.download_var('sla', dataset['sla']['sla'], dataset['sla'].attributes)
+            dataset = self.set_dataset('msla', 'u')
+            self.download_var('u_anom', dataset['u']['u'], dataset['u'].attributes)
+            self.download_var('v_anom', dataset['v']['v'], dataset['v'].attributes)
             return
 
         dataset = self.set_dataset(self.cfg['map'], 'h')
@@ -289,10 +298,13 @@ class AVISO_fetch(object):
         self.download_time(dataset)
         self.download_LonLat(dataset)
 
-        self.download_var('h', dataset['Grid_0001']['Grid_0001'], dataset['Grid_0001'].attributes)
+        if self.cfg['map'] == 'madt':
+            self.download_var('h', dataset['adt']['adt'], dataset['adt'].attributes)
+        elif self.cfg['map'] == 'msla':
+            self.download_var('sla', dataset['sla']['sla'], dataset['sla'].attributes)
         dataset = self.set_dataset(self.cfg['map'], 'u')
-        self.download_var('u', dataset['Grid_0001']['Grid_0001'], dataset['Grid_0001'].attributes)
-        self.download_var('v', dataset['Grid_0002']['Grid_0002'], dataset['Grid_0002'].attributes)
+        self.download_var('u', dataset['u']['u'], dataset['u'].attributes)
+        self.download_var('v', dataset['v']['v'], dataset['v'].attributes)
 
     def download_var(self, v, dataset, attr):
             # Will download blocks of at most 5MB
@@ -309,9 +321,10 @@ class AVISO_fetch(object):
 
             #------
             ntries = 40
-            print "Getting %s" % v
+            self.logger.info("Getting %s" % v)
             #data['h'] = ma.masked_all((len(ti),Lonlimits[-1]-Lonlimits[0], Latlimits[-1]-Latlimits[0]), dtype=numpy.float64)
-            data = self.nc.createVariable(v, 'f4', ('time', 'lat', 'lon'),
+            #dataset.type.typecode
+            data = self.nc.createVariable(v, 'i4', ('time', 'lat', 'lon'),
                     fill_value=attr['_FillValue'])
             missing_value = attr['_FillValue']
             #data.missing_value = missing_value
@@ -333,30 +346,43 @@ class AVISO_fetch(object):
             Latlimits = self.cfg['limits']['Latlimits']
 
             for b1, b2 in zip(blocks[:-1], blocks[1:]):
-                print "From %s to %s of %s" % (b1, b2, blocks[-1])
+                self.logger.debug("From %s to %s of %s" % (b1, b2, blocks[-1]))
                 ind = numpy.nonzero((ti>=b1) & (ti<b2))
                 for i in range(ntries):
-                    print "Try n: %s" % i
+                    self.logger.debug("Try n: %s" % i)
                     try:
                         if Lonlimits[1] > Lonlimits[0]:
-                            tmp = dataset[b1:b2:self.cfg['limits']['t_step'], Lonlimits[0]:Lonlimits[-1]+1,Latlimits[0]:Latlimits[-1]+1]
+                            tmp = dataset[b1:b2:self.cfg['limits']['t_step'],
+                                    Latlimits[0]:Latlimits[-1]+1,
+                                    Lonlimits[0]:Lonlimits[-1]+1]
                         else:
-                            tmp1 = dataset[b1:b2:self.cfg['limits']['t_step'], Lonlimits[0]:,Latlimits[0]:Latlimits[-1]+1]
-                            tmp2 = dataset[b1:b2:self.cfg['limits']['t_step'], :Lonlimits[-1]+1,Latlimits[0]:Latlimits[-1]+1]
+                            tmp1 = dataset[b1:b2:self.cfg['limits']['t_step'],
+                                    Latlimits[0]:Latlimits[-1]+1,
+                                    Lonlimits[0]: ]
+                            tmp2 = dataset[b1:b2:self.cfg['limits']['t_step'],
+                                    Latlimits[0]:Latlimits[-1]+1,
+                                    :Lonlimits[-1]+1]
                             tmp = np.append(tmp1, tmp2, axis=1)
 
                         if factor is not None:
                             ind_valid = tmp != missing_value
                             tmp[ind_valid] = factor * tmp[ind_valid]
 
-                        data[ind] = tmp.swapaxes(1,2).astype('f')
+                        #data[ind] = tmp.swapaxes(1,2).astype('f')
+                        data[ind] = tmp
                         break
                     except:
                         waitingtime = 30+i*20
-                        print "Failed to download. I'll try again in %ss" % waitingtime
+                        self.logger.warn(
+                            "Failed to download. I'll try again in %ss" % \
+                                    waitingtime)
                         time.sleep(waitingtime)
             #data['h'] = 1e-2*data['h'].swapaxes(1,2)
 
+            for a in attr:
+                if a not in ['units', '_FillValue']:
+                    setattr(data, a, attr[a])
+
 
 class Products(object):
     """ Calculate some products from the downloaded data
@@ -453,37 +479,6 @@ class Aviso_map(object):
     def keys(self):
         return self.data.keys()
 
-    def set_default(self):
-        """
-        """
-        if ('username' not in self.metadata) | ('password' not in self.metadata):
-            print("Aviso DAP server requires a registered username and password, sorry.")
-            return
-        if 'type' not in self.metadata:
-            self.metadata['type'] = "upd"       # upd, ref
-        if 'map' not in self.metadata:
-            self.metadata['map'] = "madt"       # madt, msla
-        if 'limits' not in self.metadata:
-            self.metadata['limits'] = {'LatIni': 0, 'LatFin': 15, 'LonIni': 296, 'LonFin': 317}
-        if 'datadir' not in self.metadata:
-            self.metadata['datadir'] = "./" #"../data"
-        if 'urlbase' not in self.metadata:
-            # Double check this. I believe now it is required to have a password,
-            #   so I should clean the option with no use/pass
-            if ('username' in self.metadata) & ('password' in self.metadata):
-                self.metadata['urlbase'] = "http://%s:%s@opendap.aviso.oceanobs.com/thredds/dodsC" % (self.metadata['username'], self.metadata['password'])
-            else:
-                self.metadata['urlbase'] = "http://opendap.aviso.oceanobs.com/thredds/dodsC"
-        if 'force_download' not in self.metadata:
-            self.metadata['force_download'] = False
-        return
-
-    def set_source_filename(self):
-        """
-        """
-        self.metadata['source_filename'] = "dataset-duacs-dt-%s-global-merged-%s" % (self.metadata['type'],self.metadata['map'])
-        return
-
     def get_data(self):
         """
         """
@@ -517,18 +512,6 @@ class Aviso_map(object):
         url_uv = "%s/%s-uv-daily" % (self.metadata['urlbase'], self.metadata['source_filename'])
         dataset_uv = open_url(url_uv)
         # ----
-        if 't_ini' not in self.metadata['limits']:
-            self.metadata['limits']['t_ini'] = 0
-        if 't_fin' not in self.metadata['limits']:
-            self.metadata['limits']['t_fin'] = dataset_h['time'].shape[0]
-        if 't_step' not in self.metadata['limits']:
-            self.metadata['limits']['t_step'] = 0
-        else:
-            print "Atention!! t_step set to: %s" % self.metadata['limits']['t_step']
-        t_ini = self.metadata['limits']['t_ini']
-        t_fin = self.metadata['limits']['t_fin']
-        t_step = self.metadata['limits']['t_step']
-        # ----
         data={}
         #
         #from coards import from_udunits
@@ -540,65 +523,12 @@ class Aviso_map(object):
             print "Problems interpreting the time"
             return
 
-        #time = self.nc.createVariable('time', 'i', ('time',))
-        #time[:] = dataset_h['time'][t_ini:t_fin:t_step]
-        #time.units = dataset_h['time'].attributes['units']
-        #data['time'] = time
-        #
-        limits=self.metadata['limits']
-        Lat=dataset_h['NbLatitudes']
-        Lon=dataset_h['NbLongitudes']
-        Latlimits=numpy.arange(Lat.shape[0])[(Lat[:]>=limits["LatIni"]) & (Lat[:]<=limits["LatFin"])]
-        Latlimits=[Latlimits[0],Latlimits[-1]]
-        Lonlimits=numpy.arange(Lon.shape[0])[(Lon[:]>=limits["LonIni"]) & (Lon[:]<=limits["LonFin"])]
-        Lonlimits=[Lonlimits[0],Lonlimits[-1]]
-
-        data['Lon'], data['Lat'] = numpy.meshgrid( (Lon[Lonlimits[0]:Lonlimits[-1]]), (Lat[Latlimits[0]:Latlimits[-1]]) )
-
-
         #------
         self.data = data
         #Arrayterator = numpy.lib.arrayterator.Arrayterator
         #dataset = dataset_h['Grid_0001']['Grid_0001']
         #ssh = Arrayterator(dataset)[t_ini:t_fin:t_step]
 
-        #blocks = 1e4
-
-        file = os.path.join(self.metadata['datadir'],self.metadata['source_filename']+".nc")
-        nc = pupynere.netcdf_file(file,'w')
-        nc.createDimension('time', len(range(t_ini,t_fin,t_step)))
-        nc.createDimension('lon', (Lonlimits[-1]-Lonlimits[0]))
-        nc.createDimension('lat', (Latlimits[-1]-Latlimits[0]))
-
-        dblocks = max(1,int(1e5/((Lonlimits[-1]-Lonlimits[0])*(Latlimits[-1]-Latlimits[0]))))
-
-        ti = numpy.arange(t_ini, t_fin, t_step)
-        blocks = ti[::dblocks]
-        if ti[-1] not in blocks:
-            blocks = numpy.append(blocks,t_fin)
-
-        ntries = 40
-        #------
-        for v, dataset, missing_value in zip(['h','u','v'], [dataset_h['Grid_0001']['Grid_0001'], dataset_uv['Grid_0001']['Grid_0001'], dataset_uv['Grid_0002']['Grid_0002']], [dataset_h['Grid_0001']._FillValue, dataset_uv['Grid_0001']._FillValue, dataset_uv['Grid_0002']._FillValue]):
-
-            print "Getting %s" % v
-            #data['h'] = ma.masked_all((len(ti),Lonlimits[-1]-Lonlimits[0], Latlimits[-1]-Latlimits[0]), dtype=numpy.float64)
-            self.data[v] = nc.createVariable(v, 'f4', ('time', 'lat', 'lon'))
-            self.data[v].missing_value = missing_value
-            for b1, b2 in zip(blocks[:-1], blocks[1:]):
-                print "From %s to %s of %s" % (b1, b2, blocks[-1])
-                ind = numpy.nonzero((ti>=b1) & (ti<b2))
-                for i in range(ntries):
-                    print "Try n: %s" % i
-                    try:
-                        self.data[v][ind] = dataset[b1:b2:t_step, Lonlimits[0]:Lonlimits[-1],Latlimits[0]:Latlimits[-1]].swapaxes(1,2).astype('f')
-                        break
-                    except:
-                        waitingtime = 30+i*20
-                        print "Failed to download. I'll try again in %ss" % waitingtime
-                        time.sleep(waitingtime)
-            #data['h'] = 1e-2*data['h'].swapaxes(1,2)
-
 
 def mask_shallow(ncfile, zfile, zlimit):
     """ Mask all variables in vars @ gridpoints shallower than mindepth
